pub struct FileEntry {
pub name: OsString,
pub kind: FileEntryKind,
pub size: Option<u64>,
pub modified: Option<OffsetDateTime>,
pub hidden: bool,
}Expand description
An entry in a directory.
Fields
name: OsStringThe name of the entry.
kind: FileEntryKindThe type of entry.
size: Option<u64>The size of the entry in bytes, if known.
modified: Option<OffsetDateTime>The last modified time of the entry, if known.
Whether this entry is considered hidden.